aboutsummaryrefslogtreecommitdiffstats
path: root/src/mds-server.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/mds-server.h9
1 files changed, 8 insertions, 1 deletions
diff --git a/src/mds-server.h b/src/mds-server.h
index b58fbcf..12cd178 100644
--- a/src/mds-server.h
+++ b/src/mds-server.h
@@ -84,13 +84,20 @@ void run_initrc(char** args);
void sigusr1_trap(int signo);
/**
* Marshal the servers state into a pipe
*
* @param fd The write end of the pipe
* @return Negative on error
*/
int marshal_server(int fd);
+/**
+ * Unmarshal the server's state from a pipe
+ *
+ * @param fd The read end of the pipe
+ */
+void unmarshal_server(int fd);
+
#endif
@@ -84,13 +84,20 @@ void run_initrc(char** args);
void sigusr1_trap(int signo);
/**
- * Marshal the servers state into a pipe
+ * Marshal the server's state into a pipe
*
* @param fd The write end of the pipe